@@ -51,6 +51,7 @@ async def sync_preseem_model(preseem_model,
                              role,
                              items,
                              packages=None,
+                             nm_model=None,
                              noact=False,
                              verbose=0):
     """
@@ -152,6 +153,7 @@ async def sync_preseem_model(preseem_model,
                 if disc.inactive:
                     changes.append('reactivated')
                     mods['inactive'] = False
+                    mods['element_uuid'] = None  # STM-9823
                 if disc.name != item.name:
                     changes.append(f'name: {disc.name} -> {item.name}')
                     mods['name'] = item.name
@@ -166,6 +168,13 @@ async def sync_preseem_model(preseem_model,
                     logging.info('sync_preseem_model(%s): modify %s (%s)',
                                  source, item, ','.join(changes))
                     if not noact:
+                        if nm_model and 'reactivated' in changes and disc.element_uuid:
+                            # STM-9823 as part of clearing the element_uuid,
+                            # we also need to delete the elem_discovery ref.
+                            ref = NetworkMetadataReference('elem_discovery',
+                                str(UUID(bytes=disc.uuid)), {})
+                            logging.info(' delete reference: %s', ref)
+                            await nm_model.del_ref(ref)
                         await call_and_log_error(
                             preseem_model.Element.UpdateElementDiscovery(
                                 company_uuid=company_uuid,
