@@ -103,13 +103,18 @@ def _pb_request(op, reqtype, **kwargs):
                     setattr(getattr(req, k), 'data', v)
             else:
                 if isinstance(v, list):
+                    # A list of a nested type
                     for x in v:
                         lv = getattr(req, k).add()
-                        for nk in f.message_type.fields_by_name:
+                        for nk, nt in f.message_type.fields_by_name.items():
                             nv = getattr(x, nk)
-                            if nv is not None:
-                                setattr(lv, nk, getattr(x, nk))
-                assert False  # TODO nested types, we don't need this yet
+                            if nt.message_type:
+                                getattr(lv, nk).CopyFrom(nv)
+                            elif nv is not None:
+                                setattr(lv, nk, nv)
+                else:
+                    # A plain nested type
+                    getattr(req, k).CopyFrom(v)
         else:
             setattr(req, k, v)
     return req
