@@ -3,6 +3,7 @@ Common classes used by this package.
 """
 import asyncio
 from collections import namedtuple
+from icmplib import async_ping
 import ipaddress
 import logging
 import time
@@ -18,35 +19,23 @@ def set_ipv6_settings(obj):
     global _ipv6_settings
     _ipv6_settings = obj
 
-# Ping code, return ping resposne time if pingable, otherwise return 0
-# The # of concurrent “ping” processes we will have running at one time
-_run_sem = None
-ping_time = 0
-async def _run(cmd):
-    global _run_sem
-    if _run_sem is None:
-        _run_sem = asyncio.Semaphore(32)
 
-    async with _run_sem:
-        proc = await asyncio.create_subprocess_shell(
-            cmd,
-            stdout=asyncio.subprocess.PIPE,
-            stderr=asyncio.subprocess.PIPE)
-        try:
-            stdout, stderr = await asyncio.wait_for(proc.communicate(), timeout=10)
-            if stdout and proc.returncode == 0:
-                # take avg value
-                ping_time = str(stdout).rsplit('min/avg/max/mdev = ')[1].split('/')[1].split('/')[0]
-            else:
-                ping_time = 0
-
-        except asyncio.TimeoutError:
-            logging.warning("Asyncio timeout for %s command", cmd)
-        return ping_time
-
-# invoke 1 ping
+_ping_sem = None  # used to prevent too many open files error
 async def ping(host):
-    return await _run("ping -c 1 -w2 " + host)
+    """Ping a host.  Returns rtt if we can ping it, 0.0 otherwise."""
+    global _ping_sem
+    if not _ping_sem:
+        _ping_sem = asyncio.Semaphore(200)
+    try:
+        async with _ping_sem:
+            result = await async_ping(host, count=1, privileged=False)
+        return result.avg_rtt
+    except asyncio.CancelledError:
+        raise
+    except Exception as err:
+        logging.warning('%s error pinging host %s: %s',
+                        type(err).__name__, host, err)
+
 
 async def http_probe(host, http_client_cls, methods=('https', 'http'), ports=None, **kwargs):
     """
